@@ -41,6 +41,11 @@ ci.coords.smooth.roc <- function(smooth.roc,
                       ) {
   if (conf.level > 1 | conf.level < 0)
     stop("'conf.level' must be within the interval [0,1].")
+  
+  if (roc.utils.is.perfect.curve(smooth.roc)) {
+  	warning("ci.coords() of a ROC curve with AUC == 1 is always a null interval and can be misleading.")
+  }
+ 
   input <- match.arg(input)
   ret <- roc.utils.match.coords.ret.args(ret)
   if (is.character(x)) {
@@ -107,6 +112,11 @@ ci.coords.roc <- function(roc,
                       ) {
   if (conf.level > 1 | conf.level < 0)
     stop("'conf.level' must be within the interval [0,1].")
+  
+  if (roc.utils.is.perfect.curve(roc)) {
+  	warning("ci.coords() of a ROC curve with AUC == 1 is always a null interval and can be misleading.")
+  }
+ 
   input <- match.arg(input)
   ret <- roc.utils.match.coords.ret.args(ret)
   if (is.character(x)) {
@@ -120,27 +130,28 @@ ci.coords.roc <- function(roc,
     progress <- roc.utils.get.progress.bar(progress, title="Coords confidence interval", label="Bootstrap in progress...", ...)
 
   if (boot.stratified) {
-    perfs <- raply(boot.n, stratified.ci.coords(roc, x, input, ret, best.method, best.weights), .progress=progress, .drop=FALSE)
+    perfs <- rlply(boot.n, stratified.ci.coords(roc, x, input, ret, best.method, best.weights), .progress=progress)
   }
   else {
-    perfs <- raply(boot.n, nonstratified.ci.coords(roc, x, input, ret, best.method, best.weights), .progress=progress, .drop=FALSE)
+    perfs <- raply(boot.n, nonstratified.ci.coords(roc, x, input, ret, best.method, best.weights), .progress=progress)
   }
 
-  if (any(is.na(perfs))) {
+  if (any(sapply(perfs, function(x) any(is.na(x))))) {
     warning("NA value(s) produced during bootstrap were ignored.")
-    perfs <- perfs[!apply(perfs, 1, function(x) any(is.na(x))),]
+    perfs <- perfs[!sapply(perfs, function(x) any(is.na(x)))]
   }
 
-  if (length(x) > 1) {
-    inputs <- paste(input, x)
-    rownames.ret <- paste(rep(inputs, each=length(ret)), ret, sep=": ")
+  if (length(x) > 1 || length(ret) > 1) {
+    ci <- t(apply(sapply(perfs, c), 1, quantile, probs=c(0+(1-conf.level)/2, .5, 1-(1-conf.level)/2)))
   }
-  else {
-    rownames.ret <- ret
+  else { # 1 x and 1 ret
+    # If x == "best" coords may return multiple best thresholds
+    # Be very conservative and take the most extreme ones
+    ci.max <- quantile(sapply(perfs, max), probs=c(0+(1-conf.level)/2, .5, 1-(1-conf.level)/2))
+    ci.min <- quantile(sapply(perfs, min), probs=c(0+(1-conf.level)/2, .5, 1-(1-conf.level)/2))
+    ci <- t(ci.max * c(0, 0.5, 1) + ci.min * c(1, 0.5, 0))
   }
-
-  ci <- t(apply(perfs, 2, quantile, probs=c(0+(1-conf.level)/2, .5, 1-(1-conf.level)/2)))
-  rownames(ci) <- rownames.ret
+  rownames(ci) <- paste(rep(paste(input, x), each=length(ret)), ret, sep=": ")
 
   class(ci) <- c("ci.coords", "ci", class(ci))
   attr(ci, "conf.level") <- conf.level
