@@ -130,6 +130,10 @@ roc.test.roc <- function(roc1, roc2,
     roc2 <- attr(roc2, "roc")
     roc2$auc <- auc2
   }
+  
+  if (roc.utils.is.perfect.curve(roc1) && roc.utils.is.perfect.curve(roc2)) {
+  	warning("roc.test() of two ROC curves with AUC == 1 has always p.value = 1 and can be misleading.")
+  }
 
   # store which objects are smoothed, and how
   smoothing.args <- list()
